#!/bin/bash
# Check for installation directory, load configuration.
USBTEMP_CMD="$USBTEMP_HOME/bin/usbtemp"
USBTEMP_CONFIG="$USBTEMP_HOME/etc/config.sh"

if [ -d "$USBTEMP_HOME" ]; then
  if [ ! -x "$USBTEMP_CMD" ]; then
    echo "Environment variable USBTEMP_HOME doesn't point to the USBtemp installation."
    exit 1
  fi
else
  echo "Env variable USBTEMP_HOME doesn't point to a directory."
  exit 1
fi

if [ -e "$USBTEMP_CONFIG" ]; then
  . "$USBTEMP_CONFIG"
else
  echo "Cannot find config file $USBTEMP_CONFIG."
  exit 1
fi

rrdtool_bin=`which rrdtool`
if [ ! -x "$rrdtool_bin" ]; then
  echo "Cannot find rrdtool executable. Exiting."
  exit 1
fi

if [ ! -d "$GRAPH_DIRECTORY" ]; then
  echo "Graph directory doesn't exist ($GRAPH_DIRECTORY), exiting."
  exit 1
fi

draw_graph_complete_last() {
  filename=$1
  title=$2
  starttime=$3
  timestamp=`date "+%d.%m.%y %k\:%M"`
  rrdtool graph "$GRAPH_DIRECTORY/$filename" \
    -a PNG --title="$title" \
    --start "$starttime" --vertical-label "Deg Celsius" \
    "DEF:probe1=$TEMP_DATABASE:probe1-temp:AVERAGE" \
    "DEF:probe2=$TEMP_DATABASE:probe2-temp:AVERAGE" \
    'LINE1:probe1#ff0000:inside  ' \
    'GPRINT:probe1:LAST:last\: %2.1lf C' \
    'GPRINT:probe1:MIN:min\: %2.1lf C' \
    'GPRINT:probe1:MAX:max\: %2.1lf C' \
    'GPRINT:probe1:AVERAGE:avg\: %2.1lf C\j' \
    'LINE1:probe2#0400ff:outside' \
    'GPRINT:probe2:LAST:last\: %2.1lf C' \
    'GPRINT:probe2:MIN:min\: %2.1lf C' \
    'GPRINT:probe2:MAX:max\: %2.1lf C' \
    'GPRINT:probe2:AVERAGE:avg\: %2.1lf C\j' \
    "COMMENT:generated by USBtemp on $timestamp\c"
#'AREA:probe3#cccccc:HVAC' \
}


draw_graph_complete () {
  filename=$1
  title=$2
  starttime=$3
  timestamp=`date "+%d.%m.%y %k\:%M"`
  rrdtool graph "$GRAPH_DIRECTORY/$filename" \
    -a PNG --title="$title" \
    --start "$starttime" --vertical-label "Deg Celsius" \
    "DEF:probe1=$TEMP_DATABASE:probe1-temp:AVERAGE" \
    "DEF:probe2=$TEMP_DATABASE:probe2-temp:AVERAGE" \
    'LINE1:probe1#ff0000:inside  ' \
    'GPRINT:probe1:MIN:min\: %2.1lf C' \
    'GPRINT:probe1:MAX:max\: %2.1lf C' \
    'GPRINT:probe1:AVERAGE:avg\: %2.1lf C\j' \
    'LINE1:probe2#0400ff:outside' \
    'GPRINT:probe2:MIN:min\: %2.1lf C' \
    'GPRINT:probe2:MAX:max\: %2.1lf C' \
    'GPRINT:probe2:AVERAGE:avg\: %2.1lf C\j' \
    "COMMENT:generated by USBtemp on $timestamp\c"
#'AREA:probe3#cccccc:HVAC' \
}

draw_graph_outside_last() {
  filename=$1
  title=$2
  starttime=$3
  timestamp=`date "+%d.%m.%y %k\:%M"`
  rrdtool graph "$GRAPH_DIRECTORY/$filename" \
    -a PNG --title="$title" \
    --start "$starttime" --vertical-label "Deg Celsius" \
    "DEF:probe1=$TEMP_DATABASE:probe1-temp:AVERAGE" \
    "DEF:probe2=$TEMP_DATABASE:probe2-temp:AVERAGE" \
    'LINE1:probe2#0400ff:outside' \
    'GPRINT:probe2:LAST:last\: %2.1lf C' \
    'GPRINT:probe2:MIN:min\: %2.1lf C' \
    'GPRINT:probe2:MAX:max\: %2.1lf C' \
    'GPRINT:probe2:AVERAGE:avg\: %2.1lf C\j' \
    "COMMENT:generated by USBtemp on $timestamp\c"
}

draw_graph_outside() {
  filename=$1
  title=$2
  starttime=$3
  timestamp=`date "+%d.%m.%y %k\:%M"`
  rrdtool graph "$GRAPH_DIRECTORY/$filename" \
    -a PNG --title="$title" \
    --start "$starttime" --vertical-label "Deg Celsius" \
    "DEF:probe1=$TEMP_DATABASE:probe1-temp:AVERAGE" \
    "DEF:probe2=$TEMP_DATABASE:probe2-temp:AVERAGE" \
    'LINE1:probe2#0400ff:outside' \
    'GPRINT:probe2:MIN:min\: %2.1lf C' \
    'GPRINT:probe2:MAX:max\: %2.1lf C' \
    'GPRINT:probe2:AVERAGE:avg\: %2.1lf C\j' \
    "COMMENT:generated by USBtemp on $timestamp\c"
}


# commands to generate graphs follow. You can add or modify the 
# examples below. Syntax is:
# draw_graph_ <filename> <title> <time modifier> <features>
# where features is 
draw_graph_complete_last "last-24-hours.png" "Temperature - last 24 hours" "-1day"
draw_graph_complete "last-week.png" "Temperature - last week" "-1week"
draw_graph_complete "last-month.png" "Temperature - last month" "-1month"
draw_graph_complete "last-year.png" "Temperature - last year" "-1year"
draw_graph_outside_last "outside-last-24-hours.png" "Temperature - last 24 hours" "-1day"
draw_graph_outside "outside-last-week.png" "Temperature - last week" "-1week"
draw_graph_outside "outside-last-month.png" "Temperature - last month" "-1month"
draw_graph_outside "outside-last-year.png" "Temperature - last year" "-1year"
